@@ -1586,7 +1586,9 @@ def system(
                 out_frame_record = inspect.stack()[caller]
                 o_fn = lambda text: log( text, caller=out_frame_record, nv=False, raw=True)
             elif isinstance(o, int):
-                o_fn = lambda text: os.write( o, text)
+                def fn(text, o=o):
+                    os.write(o, text.encode())
+                o_fn = fn
             elif callable(o):
                 o_fn = o
             else:
@@ -1596,10 +1598,18 @@ def system(
                             ' or support o() or o.write().'
                             )
                 o_decoder = decoders_ensure(o.encoding)
-                def fn(text):
-                    o.write(text)
+                def o_fn(text, o=o):
+                    if errors == 'strict':
+                        o.write(text)
+                    else:
+                        # This is probably only necessary on Windows, where
+                        # sys.stdout can be cp1252 and will sometimes raise
+                        # UnicodeEncodeError. We hard-ignore these errors.
+                        try:
+                            o.write(text)
+                        except Exception as e:
+                            o.write(f'\n[Ignoring Exception: {e}]\n')
                     o.flush()   # Seems to be necessary on Windows.
-                o_fn = fn
             if o_prefix:
                 o_fn = StreamPrefix( o_fn, o_prefix).write
             if not o_decoder:
@@ -2106,7 +2116,7 @@ def fs_newer( pattern, t):
     paths = glob.glob(pattern)
     paths_new = []
     for path in paths:
-        tt = os.path.getmtime(path)
+        tt = fs_mtime(path)
         if tt >= t:
             paths_new.append(path)
     return paths_new
